@@ -23,6 +23,7 @@ from . import (
     pysbuiltins,
     results,
     runner,
+    shell,
     symtab,
     token,
     utils,
@@ -50,6 +51,7 @@ __all__ = (
     'pysbuiltins',
     'results',
     'runner',
+    'shell',
     'symtab',
     'token',
     'utils',
